<?php
/**
 * PeachPay gateway table.
 *
 * @var array $gateway_list A list of gateway instances to render.
 *
 * @package PeachPay
 */

defined( 'PEACHPAY_ABSPATH' ) || exit;

foreach ( $gateway_list as $gateway ) : ?>
	<div class="gateway row v-align-middle">
		<div class="col-1">
			<input class="toggle" type="checkbox" onclick="stopPopupOnSubmit()" data-id="<?php echo esc_html( $gateway->id ); ?>" <?php checked( 'yes', $gateway->enabled, true ); ?>>
		</div>
		<div class="col-9">
			<div class="row v-align-middle">
				<?php
                // PHPCS:ignore
				echo $gateway->get_icon();
				?>
				<h4><?php echo esc_html( $gateway->title ); ?></h4>
				<span> - </span>
				<p class="description">
					<?php echo esc_html( $gateway->method_description ); ?>
				</p>
				<div class="tooltip">
					<img class="tooltip-info-img" src="<?php echo esc_url( PeachPay::get_asset_url( 'img/dot-dot-dot.svg' ) ); ?>">
					<span class="tooltip-body left" style="max-width: 40rem;">
						<span>
							<h4><?php esc_html_e( 'Currency availability' ); ?></h4>
							<p>
							<?php
							$currencies = $gateway->get_supported_currencies();

							if ( is_array( $currencies ) ) {
								if ( count( $currencies ) > 0 ) {
									echo esc_html( implode( ', ', $currencies ) );
								} else {
									esc_html_e( 'No supported currencies', 'peachpay-for-woocommerce' );
								}
							} else {
								esc_html_e( 'Not restricted', 'peachpay-for-woocommerce' );
							}
							?>
							</p>
						</span>
						<span>
							<h4><?php esc_html_e( 'Country availability' ); ?></h4>
							<p>
							<?php
							$countries = $gateway->get_supported_countries();

							if ( is_array( $countries ) ) {
								if ( count( $countries ) > 0 ) {
									echo esc_html( implode( ', ', $countries ) );
								} else {
									esc_html_e( 'No supported countries', 'peachpay-for-woocommerce' );
								}
							} else {
								esc_html_e( 'Not restricted', 'peachpay-for-woocommerce' );
							}
							?>
							</p>
						</span>
						<span>
							<h4><?php esc_html_e( 'Minimum charge' ); ?></h4>
							<p>
							<?php
							$minimum = $gateway->get_minimum_charge();
							if ( is_numeric( $minimum ) ) {
                                // PHPCS:ignore
                                echo wc_price( $minimum, array( 'currency' => $gateway->min_max_currency ) );
							} else {
								esc_html_e( 'Not restricted', 'peachpay-for-woocommerce' );
							}
							?>
							</p>
						</span>
						<span>
							<h4><?php esc_html_e( 'Maximum charge' ); ?></h4>
							<p>
							<?php
							$maximum = $gateway->get_maximum_charge();
							if ( INF !== $maximum ) {
								// PHPCS:ignore
								echo wc_price( $maximum, array( 'currency' => $gateway->min_max_currency ) );
							} else {
								esc_html_e( 'Not restricted', 'peachpay-for-woocommerce' );
							}
							?>
							</p>
						</span>
					</span>
				</div>
			</div>
		</div>
		<div class="col-2 flex-row jc-end">
			<a class="button-secondary pp-button-secondary" href="<?php echo esc_url( $gateway->get_settings_url() ); ?>">
				<?php
				if ( $gateway->needs_setup() ) {
					esc_html_e( 'Set up', 'peachpay-for-woocommerce' );
				} else {
					esc_html_e( 'Configure', 'peachpay-for-woocommerce' );
				}
				?>
			</a>
		</div>
	</div>
<?php endforeach; ?>
