<?php
/**
 * Helper functions for rendering parts of the view.
 *
 * @package PeachPay
 */

defined( 'PEACHPAY_ABSPATH' ) || exit;

if ( function_exists( 'peachpay_generate_misc_link' ) ) {
	// Since the view templates can be included multiple times, if one of these
	// functions has already been defined, then we return to avoid an error.
	return;
}

/**
 * Generates a styled link on the top right of PeachPay settings header.
 *
 * @param string $link   The url.
 * @param string $icon   The file name of the icon.
 * @param string $title  The text to display on the link.
 */
function peachpay_generate_misc_link( $link, $icon, $title ) {
	?>
	<a class="misc-link <?php echo esc_attr( $icon ); ?>-link" href="<?php echo esc_url( $link ); ?>" target="_blank">
		<div class="icon <?php echo esc_attr( $icon ); ?>"></div>
		<?php peachpay_generate_nav_tab_title( $title ); ?>
	</a>
	<?php
}

/**
 * Generates a single navigation tab for the given tab and section.
 *
 * @param string $tab         The tab key.
 * @param string $section     The section key.
 * @param string $title       The text to display on the tab.
 * @param string $current_tab The current selected tab; used for styling.
 */
function peachpay_generate_nav_tab( $tab, $section, $title, $current_tab ) {
	if ( $tab === $current_tab || 'payment' === $tab && 'checkout' === $current_tab ) {
		?>
		<div class="nav-tab nav-tab-active"><?php peachpay_generate_nav_tab_title( $title ); ?></div>
	<?php } else { ?>
		<a class="nav-tab" href="<?php esc_url( PeachPay_Admin::admin_settings_url( 'peachpay', $tab, $section ) ); ?>">
			<?php peachpay_generate_nav_tab_title( $title ); ?>
		</a>
		<?php
	}
}

/**
 * Generates escaped and translated text for the navigation tab title.
 * This is a workaround for esc_html_e only accepting string literals.
 *
 * @param string $title The text to display on the tab.
 */
function peachpay_generate_nav_tab_title( $title ) {
	switch ( $title ) {
		case 'Payments':
			echo esc_html_e( 'Payments', 'peachpay-for-woocommerce' );
			break;
		case 'Currency':
			echo esc_html_e( 'Currency', 'peachpay-for-woocommerce' );
			break;
		case 'Field editor':
			echo esc_html_e( 'Field editor', 'peachpay-for-woocommerce' );
			break;
		case 'Recommended products':
			echo esc_html_e( 'Recommended products', 'peachpay-for-woocommerce' );
			break;
		case 'Express checkout':
			echo esc_html_e( 'Express checkout', 'peachpay-for-woocommerce' );
			break;
		case 'Docs':
			echo esc_html_e( 'Docs', 'peachpay-for-woocommerce' );
			break;
		case 'Support':
			echo esc_html_e( 'Support', 'peachpay-for-woocommerce' );
			break;
		case 'Analytics':
			echo esc_html_e( 'Analytics', 'peachpay-for-woocommerce' );
			break;
	}
}
