<?php
/**
 * PeachPay PayPal gateway utility trait.
 *
 * @package PeachPay
 */

defined( 'PEACHPAY_ABSPATH' ) || exit;


trait PeachPay_PayPal_Gateway_Utilities {

	/**
	 * Gets the URL to redirect the frontend to for confirming the payment.
	 *
	 * @param WC_Order $order The order the payment intent was created for.
	 * @param string   $order_id The PayPal order id.
	 */
	protected function paypal_order_frontend_response( $order, $order_id ) {
		$data = rawurlencode(
            // PHPCS:ignore
			base64_encode(
				wp_json_encode(
					array(
						'type'           => 'paypal',
						'transaction_id' => PeachPay_PayPal_Order_data::get_peachpay( $order, 'transaction_id' ),
						'order_id'       => $order->get_id(),
						'gateway'        => $order->get_payment_method(),
						'success_url'    => $order->get_checkout_order_received_url(),
						'cancel_url'     => str_replace( '&amp;', '&', $order->get_cancel_order_url() ),
						'data'           => array(
							'id' => $order_id,
						),
					)
				)
			)
		);

		return wc_get_checkout_url() . '#payment_data=' . $data;
	}

	/**
	 * Gets the PayPal order line items.
	 *
	 * @param WC_Order $order The order to retrieve line items from.
	 */
	public static function get_paypal_order_line_items( $order ) {
		$line_items = array();
		foreach ( $order->get_items( 'line_item' ) as $item ) {
			$product      = $item->get_product();
			$line_items[] = array(
				'name'        => $product->get_title(),
				'quantity'    => strval( $item->get_quantity() ),
				'unit_amount' => array(
					'currency_code' => $order->get_currency(),
					'value'         => strval( $product->get_price() ),
				),
				'category'    => $product->is_virtual() ? 'DIGITAL_GOODS' : 'PHYSICAL_GOODS',
				'sku'         => $product->get_sku() ? $product->get_sku() : '',
			);
		}

		return $line_items;
	}
}
