<?php
/**
 * PeachPay Square payment integration.
 *
 * @package PeachPay
 */

if ( ! defined( 'PEACHPAY_ABSPATH' ) ) {
	exit;
}

/**
 * .
 */
final class PeachPay_Square_Integration {
	use PeachPay_Payment_Integration;

	/**
	 * At some point in time we will allow the ability to disable and enable
	 * integrations completely to ensure they do not have performance impacts
	 * when not used. For now we always return true.
	 */
	public static function should_load() {
		return true;
	}

	/**
	 * .
	 */
	private function includes() {
		require_once PEACHPAY_ABSPATH . 'core/payments/square/hooks.php';
		require_once PEACHPAY_ABSPATH . 'core/payments/square/functions.php';

		if ( is_admin() ) {
			require_once PEACHPAY_ABSPATH . 'core/payments/square/admin/class-peachpay-admin-square-integration.php';
		}
	}

	/**
	 * .
	 */
	protected function woocommerce_init() {
		require_once PEACHPAY_ABSPATH . 'core/payments/square/abstract/class-peachpay-square-payment-gateway.php';

		require_once PEACHPAY_ABSPATH . 'core/payments/square/gateways/class-peachpay-square-card-gateway.php';
		require_once PEACHPAY_ABSPATH . 'core/payments/square/gateways/class-peachpay-square-applepay-gateway.php';
		require_once PEACHPAY_ABSPATH . 'core/payments/square/gateways/class-peachpay-square-googlepay-gateway.php';

		$this->payment_gateways[] = 'PeachPay_Square_Card_Gateway';
		$this->payment_gateways[] = 'PeachPay_Square_ApplePay_Gateway';
		$this->payment_gateways[] = 'PeachPay_Square_GooglePay_Gateway';
	}

	/**
	 * Used to detect if a gateway is a PeachPay Square gateway.
	 *
	 * @param string $id Payment gateway id.
	 */
	public static function is_payment_gateway( $id ) {
		return str_starts_with( $id, 'peachpay_square_' );
	}
}
PeachPay_Square_Integration::instance();
